/* DataImportsUI.c generated by valac 0.40.4, the Vala compiler
 * generated from DataImportsUI.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include "shotwell-plugin-dev-1.0.h"
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>


#define DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE (data_imports_ui_concrete_dialog_pane_get_type ())
#define DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPane))
#define DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPaneClass))
#define DATA_IMPORTS_UI_IS_CONCRETE_DIALOG_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE))
#define DATA_IMPORTS_UI_IS_CONCRETE_DIALOG_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE))
#define DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPaneClass))

typedef struct _DataImportsUIConcreteDialogPane DataImportsUIConcreteDialogPane;
typedef struct _DataImportsUIConcreteDialogPaneClass DataImportsUIConcreteDialogPaneClass;
typedef struct _DataImportsUIConcreteDialogPanePrivate DataImportsUIConcreteDialogPanePrivate;
enum  {
	DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE_0_PROPERTY,
	DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE_NUM_PROPERTIES
};
static GParamSpec* data_imports_ui_concrete_dialog_pane_properties[DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE (data_imports_ui_static_message_pane_get_type ())
#define DATA_IMPORTS_UI_STATIC_MESSAGE_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE, DataImportsUIStaticMessagePane))
#define DATA_IMPORTS_UI_STATIC_MESSAGE_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE, DataImportsUIStaticMessagePaneClass))
#define DATA_IMPORTS_UI_IS_STATIC_MESSAGE_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE))
#define DATA_IMPORTS_UI_IS_STATIC_MESSAGE_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE))
#define DATA_IMPORTS_UI_STATIC_MESSAGE_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE, DataImportsUIStaticMessagePaneClass))

typedef struct _DataImportsUIStaticMessagePane DataImportsUIStaticMessagePane;
typedef struct _DataImportsUIStaticMessagePaneClass DataImportsUIStaticMessagePaneClass;
typedef struct _DataImportsUIStaticMessagePanePrivate DataImportsUIStaticMessagePanePrivate;
enum  {
	DATA_IMPORTS_UI_STATIC_MESSAGE_PANE_0_PROPERTY,
	DATA_IMPORTS_UI_STATIC_MESSAGE_PANE_NUM_PROPERTIES
};
static GParamSpec* data_imports_ui_static_message_pane_properties[DATA_IMPORTS_UI_STATIC_MESSAGE_PANE_NUM_PROPERTIES];

#define DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE (data_imports_ui_library_selection_pane_get_type ())
#define DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, DataImportsUILibrarySelectionPane))
#define DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, DataImportsUILibrarySelectionPaneClass))
#define DATA_IMPORTS_UI_IS_LIBRARY_SELECTION_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE))
#define DATA_IMPORTS_UI_IS_LIBRARY_SELECTION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE))
#define DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, DataImportsUILibrarySelectionPaneClass))

typedef struct _DataImportsUILibrarySelectionPane DataImportsUILibrarySelectionPane;
typedef struct _DataImportsUILibrarySelectionPaneClass DataImportsUILibrarySelectionPaneClass;
typedef struct _DataImportsUILibrarySelectionPanePrivate DataImportsUILibrarySelectionPanePrivate;
enum  {
	DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE_0_PROPERTY,
	DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE_NUM_PROPERTIES
};
static GParamSpec* data_imports_ui_library_selection_pane_properties[DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block11Data Block11Data;
typedef struct _Block12Data Block12Data;

#define DATA_IMPORTS_UI_TYPE_PROGRESS_PANE (data_imports_ui_progress_pane_get_type ())
#define DATA_IMPORTS_UI_PROGRESS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, DataImportsUIProgressPane))
#define DATA_IMPORTS_UI_PROGRESS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, DataImportsUIProgressPaneClass))
#define DATA_IMPORTS_UI_IS_PROGRESS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE))
#define DATA_IMPORTS_UI_IS_PROGRESS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE))
#define DATA_IMPORTS_UI_PROGRESS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, DataImportsUIProgressPaneClass))

typedef struct _DataImportsUIProgressPane DataImportsUIProgressPane;
typedef struct _DataImportsUIProgressPaneClass DataImportsUIProgressPaneClass;
typedef struct _DataImportsUIProgressPanePrivate DataImportsUIProgressPanePrivate;
enum  {
	DATA_IMPORTS_UI_PROGRESS_PANE_0_PROPERTY,
	DATA_IMPORTS_UI_PROGRESS_PANE_NUM_PROPERTIES
};
static GParamSpec* data_imports_ui_progress_pane_properties[DATA_IMPORTS_UI_PROGRESS_PANE_NUM_PROPERTIES];

#define DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG (data_imports_ui_data_imports_dialog_get_type ())
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialog))
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialogClass))
#define DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG))
#define DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG))
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialogClass))

typedef struct _DataImportsUIDataImportsDialog DataImportsUIDataImportsDialog;
typedef struct _DataImportsUIDataImportsDialogClass DataImportsUIDataImportsDialogClass;
typedef struct _DataImportsUIDataImportsDialogPrivate DataImportsUIDataImportsDialogPrivate;

#define PLUGINS_TYPE_STANDARD_HOST_INTERFACE (plugins_standard_host_interface_get_type ())
#define PLUGINS_STANDARD_HOST_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface))
#define PLUGINS_STANDARD_HOST_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterfaceClass))
#define PLUGINS_IS_STANDARD_HOST_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE))
#define PLUGINS_IS_STANDARD_HOST_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PLUGINS_TYPE_STANDARD_HOST_INTERFACE))
#define PLUGINS_STANDARD_HOST_INTERFACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterfaceClass))

typedef struct _PluginsStandardHostInterface PluginsStandardHostInterface;
typedef struct _PluginsStandardHostInterfaceClass PluginsStandardHostInterfaceClass;

#define SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST (spit_data_imports_concrete_data_imports_host_get_type ())
#define SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost))
#define SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHostClass))
#define SPIT_DATA_IMPORTS_IS_CONCRETE_DATA_IMPORTS_HOST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST))
#define SPIT_DATA_IMPORTS_IS_CONCRETE_DATA_IMPORTS_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST))
#define SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHostClass))

typedef struct _SpitDataImportsConcreteDataImportsHost SpitDataImportsConcreteDataImportsHost;
typedef struct _SpitDataImportsConcreteDataImportsHostClass SpitDataImportsConcreteDataImportsHostClass;
enum  {
	DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_0_PROPERTY,
	DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_NUM_PROPERTIES
};
static GParamSpec* data_imports_ui_data_imports_dialog_properties[DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_NUM_PROPERTIES];

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _DataImportsUIConcreteDialogPane {
	GObject parent_instance;
	DataImportsUIConcreteDialogPanePrivate * priv;
};

struct _DataImportsUIConcreteDialogPaneClass {
	GObjectClass parent_class;
};

struct _DataImportsUIConcreteDialogPanePrivate {
	GtkBox* pane_widget;
};

struct _DataImportsUIStaticMessagePane {
	DataImportsUIConcreteDialogPane parent_instance;
	DataImportsUIStaticMessagePanePrivate * priv;
};

struct _DataImportsUIStaticMessagePaneClass {
	DataImportsUIConcreteDialogPaneClass parent_class;
};

struct _DataImportsUILibrarySelectionPane {
	DataImportsUIConcreteDialogPane parent_instance;
	DataImportsUILibrarySelectionPanePrivate * priv;
};

struct _DataImportsUILibrarySelectionPaneClass {
	DataImportsUIConcreteDialogPaneClass parent_class;
};

struct _DataImportsUILibrarySelectionPanePrivate {
	SpitDataImportsPluginHost* host;
	SpitDataImportsImportableLibrary* selected_library;
	GFile* selected_file;
	GtkButton* import_button;
	GtkRadioButton* file_radio;
};

struct _Block11Data {
	int _ref_count_;
	DataImportsUILibrarySelectionPane* self;
	GtkFileChooserButton* file_chooser;
};

struct _Block12Data {
	int _ref_count_;
	DataImportsUILibrarySelectionPane* self;
	GtkRadioButton* button;
	SpitDataImportsImportableLibrary* library;
};

struct _DataImportsUIProgressPane {
	DataImportsUIConcreteDialogPane parent_instance;
	DataImportsUIProgressPanePrivate * priv;
};

struct _DataImportsUIProgressPaneClass {
	DataImportsUIConcreteDialogPaneClass parent_class;
};

struct _DataImportsUIProgressPanePrivate {
	GtkLabel* message_label;
	GtkLabel* progress_label;
	GtkProgressBar* progress_bar;
};

struct _DataImportsUIDataImportsDialog {
	GtkDialog parent_instance;
	DataImportsUIDataImportsDialogPrivate * priv;
};

struct _DataImportsUIDataImportsDialogClass {
	GtkDialogClass parent_class;
};

struct _DataImportsUIDataImportsDialogPrivate {
	GtkComboBoxText* service_selector_box;
	GtkBox* central_area_layouter;
	GtkButton* close_cancel_button;
	SpitDataImportsDialogPane* active_pane;
	SpitDataImportsConcreteDataImportsHost* host;
};


static gpointer data_imports_ui_concrete_dialog_pane_parent_class = NULL;
static SpitDataImportsDialogPaneIface * data_imports_ui_concrete_dialog_pane_spit_data_imports_dialog_pane_parent_iface = NULL;
static gpointer data_imports_ui_static_message_pane_parent_class = NULL;
static gpointer data_imports_ui_library_selection_pane_parent_class = NULL;
static gpointer data_imports_ui_progress_pane_parent_class = NULL;
static gpointer data_imports_ui_data_imports_dialog_parent_class = NULL;
static DataImportsUIDataImportsDialog* data_imports_ui_data_imports_dialog_instance;
static DataImportsUIDataImportsDialog* data_imports_ui_data_imports_dialog_instance = NULL;

#define DATA_IMPORTS_UI_NO_PLUGINS_ENABLED_MESSAGE _ ("You do not have any data imports plugins enabled.\n" \
"\n" \
"In order to use the Import From Application functionality, you need to" \
" have at least one data imports plugin enabled. Plugins can be enabled" \
" in the Preferences dialog.")
GType data_imports_ui_concrete_dialog_pane_get_type (void) G_GNUC_CONST;
#define DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPanePrivate))
DataImportsUIConcreteDialogPane* data_imports_ui_concrete_dialog_pane_new (void);
DataImportsUIConcreteDialogPane* data_imports_ui_concrete_dialog_pane_construct (GType object_type);
static GtkWidget* data_imports_ui_concrete_dialog_pane_real_get_widget (SpitDataImportsDialogPane* base);
static SpitDataImportsDialogPaneGeometryOptions data_imports_ui_concrete_dialog_pane_real_get_preferred_geometry (SpitDataImportsDialogPane* base);
static void data_imports_ui_concrete_dialog_pane_real_on_pane_installed (SpitDataImportsDialogPane* base);
static void data_imports_ui_concrete_dialog_pane_real_on_pane_uninstalled (SpitDataImportsDialogPane* base);
static void data_imports_ui_concrete_dialog_pane_finalize (GObject * obj);
GType data_imports_ui_static_message_pane_get_type (void) G_GNUC_CONST;
DataImportsUIStaticMessagePane* data_imports_ui_static_message_pane_new (const gchar* message_string);
DataImportsUIStaticMessagePane* data_imports_ui_static_message_pane_construct (GType object_type,
                                                                               const gchar* message_string);
DataImportsUIStaticMessagePane* data_imports_ui_static_message_pane_new_with_pango (const gchar* msg);
DataImportsUIStaticMessagePane* data_imports_ui_static_message_pane_construct_with_pango (GType object_type,
                                                                                          const gchar* msg);
GType data_imports_ui_library_selection_pane_get_type (void) G_GNUC_CONST;
#define DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, DataImportsUILibrarySelectionPanePrivate))
DataImportsUILibrarySelectionPane* data_imports_ui_library_selection_pane_new (SpitDataImportsPluginHost* host,
                                                                               const gchar* welcome_message,
                                                                               SpitDataImportsImportableLibrary** discovered_libraries,
                                                                               int discovered_libraries_length1,
                                                                               const gchar* file_select_label);
DataImportsUILibrarySelectionPane* data_imports_ui_library_selection_pane_construct (GType object_type,
                                                                                     SpitDataImportsPluginHost* host,
                                                                                     const gchar* welcome_message,
                                                                                     SpitDataImportsImportableLibrary** discovered_libraries,
                                                                                     int discovered_libraries_length1,
                                                                                     const gchar* file_select_label);
static void data_imports_ui_library_selection_pane_on_file_selected (DataImportsUILibrarySelectionPane* self,
                                                              GFile* file);
static GtkRadioButton* data_imports_ui_library_selection_pane_create_radio_button (DataImportsUILibrarySelectionPane* self,
                                                                            GtkBox* box,
                                                                            GtkRadioButton* group,
                                                                            SpitDataImportsImportableLibrary* library,
                                                                            const gchar* label,
                                                                            gint margin_left,
                                                                            gint margin_right);
static Block11Data* block11_data_ref (Block11Data* _data11_);
static void block11_data_unref (void * _userdata_);
static void ___lambda23_ (Block11Data* _data11_);
static void data_imports_ui_library_selection_pane_set_import_button_sensitivity (DataImportsUILibrarySelectionPane* self);
static void ____lambda23__gtk_file_chooser_selection_changed (GtkFileChooser* _sender,
                                                       gpointer self);
static void __lambda24_ (DataImportsUILibrarySelectionPane* self);
static void data_imports_ui_library_selection_pane_on_library_selected (DataImportsUILibrarySelectionPane* self,
                                                                 SpitDataImportsImportableLibrary* library);
static void ___lambda24__gtk_button_clicked (GtkButton* _sender,
                                      gpointer self);
static Block12Data* block12_data_ref (Block12Data* _data12_);
static void block12_data_unref (void * _userdata_);
static void __lambda22_ (Block12Data* _data12_);
static void ___lambda22__gtk_toggle_button_toggled (GtkToggleButton* _sender,
                                             gpointer self);
static void data_imports_ui_library_selection_pane_finalize (GObject * obj);
GType data_imports_ui_progress_pane_get_type (void) G_GNUC_CONST;
#define DATA_IMPORTS_UI_PROGRESS_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, DataImportsUIProgressPanePrivate))
DataImportsUIProgressPane* data_imports_ui_progress_pane_new (const gchar* message);
DataImportsUIProgressPane* data_imports_ui_progress_pane_construct (GType object_type,
                                                                    const gchar* message);
void data_imports_ui_progress_pane_update_progress (DataImportsUIProgressPane* self,
                                                    gdouble progress,
                                                    const gchar* progress_message);
void spin_event_loop (void);
static void data_imports_ui_progress_pane_finalize (GObject * obj);
GType data_imports_ui_data_imports_dialog_get_type (void) G_GNUC_CONST;
GType plugins_standard_host_interface_get_type (void) G_GNUC_CONST;
GType spit_data_imports_concrete_data_imports_host_get_type (void) G_GNUC_CONST;
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialogPrivate))
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_LARGE_WINDOW_WIDTH 860
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_LARGE_WINDOW_HEIGHT 688
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_COLOSSAL_WINDOW_WIDTH 1024
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_COLOSSAL_WINDOW_HEIGHT 688
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_STANDARD_WINDOW_WIDTH 600
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_STANDARD_WINDOW_HEIGHT 510
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_BORDER_REGION_WIDTH 16
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_BORDER_REGION_HEIGHT 100
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_STANDARD_CONTENT_LABEL_WIDTH 500
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_STANDARD_ACTION_BUTTON_WIDTH 128
DataImportsUIDataImportsDialog* data_imports_ui_data_imports_dialog_new (void);
DataImportsUIDataImportsDialog* data_imports_ui_data_imports_dialog_construct (GType object_type);
gint resources_use_header_bar (void);
static gboolean data_imports_ui_data_imports_dialog_on_window_close (DataImportsUIDataImportsDialog* self,
                                                              GdkEventAny* evt);
static gboolean _data_imports_ui_data_imports_dialog_on_window_close_gtk_widget_delete_event (GtkWidget* _sender,
                                                                                       GdkEventAny* event,
                                                                                       gpointer self);
SpitDataImportsService** spit_data_imports_load_services (gboolean load_all,
                                                          int* result_length1);
GType configuration_facade_get_type (void) G_GNUC_CONST;
GType config_facade_get_type (void) G_GNUC_CONST;
ConfigFacade* config_facade_get_instance (void);
gchar* configuration_facade_get_last_used_dataimports_service (ConfigurationFacade* self);
static void data_imports_ui_data_imports_dialog_on_service_changed (DataImportsUIDataImportsDialog* self);
static void _data_imports_ui_data_imports_dialog_on_service_changed_gtk_combo_box_changed (GtkComboBox* _sender,
                                                                                    gpointer self);
static void data_imports_ui_data_imports_dialog_on_close_cancel_clicked (DataImportsUIDataImportsDialog* self);
static void _data_imports_ui_data_imports_dialog_on_close_cancel_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                      gpointer self);
static void data_imports_ui_data_imports_dialog_set_standard_window_mode (DataImportsUIDataImportsDialog* self);
void data_imports_ui_data_imports_dialog_install_pane (DataImportsUIDataImportsDialog* self,
                                                       SpitDataImportsDialogPane* pane);
void data_imports_ui_data_imports_dialog_set_close_button_mode (DataImportsUIDataImportsDialog* self);
DataImportsUIDataImportsDialog* data_imports_ui_data_imports_dialog_get_or_create_instance (void);
void data_imports_ui_data_imports_dialog_terminate_instance (void);
static void data_imports_ui_data_imports_dialog_terminate (DataImportsUIDataImportsDialog* self);
SpitDataImportsService** spit_data_imports_load_all_services (int* result_length1);
void configuration_facade_set_last_used_dataimports_service (ConfigurationFacade* self,
                                                             const gchar* service_name);
SpitDataImportsConcreteDataImportsHost* spit_data_imports_concrete_data_imports_host_new (SpitDataImportsService* service,
                                                                                          DataImportsUIDataImportsDialog* dialog);
SpitDataImportsConcreteDataImportsHost* spit_data_imports_concrete_data_imports_host_construct (GType object_type,
                                                                                                SpitDataImportsService* service,
                                                                                                DataImportsUIDataImportsDialog* dialog);
static void data_imports_ui_data_imports_dialog_set_large_window_mode (DataImportsUIDataImportsDialog* self);
static void data_imports_ui_data_imports_dialog_set_colossal_window_mode (DataImportsUIDataImportsDialog* self);
static void data_imports_ui_data_imports_dialog_set_free_sizable_window_mode (DataImportsUIDataImportsDialog* self);
static void data_imports_ui_data_imports_dialog_clear_free_sizable_window_mode (DataImportsUIDataImportsDialog* self);
SpitDataImportsDialogPane* data_imports_ui_data_imports_dialog_get_active_pane (DataImportsUIDataImportsDialog* self);
void data_imports_ui_data_imports_dialog_set_cancel_button_mode (DataImportsUIDataImportsDialog* self);
void data_imports_ui_data_imports_dialog_lock_service (DataImportsUIDataImportsDialog* self);
void data_imports_ui_data_imports_dialog_unlock_service (DataImportsUIDataImportsDialog* self);
static void data_imports_ui_data_imports_dialog_finalize (GObject * obj);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);


DataImportsUIConcreteDialogPane*
data_imports_ui_concrete_dialog_pane_construct (GType object_type)
{
	DataImportsUIConcreteDialogPane * self = NULL;
	GtkBox* _tmp0_;
#line 15 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = (DataImportsUIConcreteDialogPane*) g_object_new (object_type, NULL);
#line 16 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
#line 16 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp0_);
#line 16 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 16 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->pane_widget = _tmp0_;
#line 15 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return self;
#line 396 "DataImportsUI.c"
}


DataImportsUIConcreteDialogPane*
data_imports_ui_concrete_dialog_pane_new (void)
{
#line 15 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return data_imports_ui_concrete_dialog_pane_construct (DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE);
#line 405 "DataImportsUI.c"
}


static gpointer
_g_object_ref0 (gpointer self)
{
#line 20 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return self ? g_object_ref (self) : NULL;
#line 414 "DataImportsUI.c"
}


static GtkWidget*
data_imports_ui_concrete_dialog_pane_real_get_widget (SpitDataImportsDialogPane* base)
{
	DataImportsUIConcreteDialogPane * self;
	GtkWidget* result = NULL;
	GtkBox* _tmp0_;
	GtkWidget* _tmp1_;
#line 19 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPane);
#line 20 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->pane_widget;
#line 20 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 20 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	result = _tmp1_;
#line 20 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return result;
#line 435 "DataImportsUI.c"
}


static SpitDataImportsDialogPaneGeometryOptions
data_imports_ui_concrete_dialog_pane_real_get_preferred_geometry (SpitDataImportsDialogPane* base)
{
	DataImportsUIConcreteDialogPane * self;
	SpitDataImportsDialogPaneGeometryOptions result = 0;
#line 23 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPane);
#line 24 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	result = SPIT_DATA_IMPORTS_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 24 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return result;
#line 450 "DataImportsUI.c"
}


static void
data_imports_ui_concrete_dialog_pane_real_on_pane_installed (SpitDataImportsDialogPane* base)
{
	DataImportsUIConcreteDialogPane * self;
#line 27 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPane);
#line 460 "DataImportsUI.c"
}


static void
data_imports_ui_concrete_dialog_pane_real_on_pane_uninstalled (SpitDataImportsDialogPane* base)
{
	DataImportsUIConcreteDialogPane * self;
#line 30 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPane);
#line 470 "DataImportsUI.c"
}


static void
data_imports_ui_concrete_dialog_pane_class_init (DataImportsUIConcreteDialogPaneClass * klass)
{
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_concrete_dialog_pane_parent_class = g_type_class_peek_parent (klass);
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_type_class_add_private (klass, sizeof (DataImportsUIConcreteDialogPanePrivate));
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_ui_concrete_dialog_pane_finalize;
#line 483 "DataImportsUI.c"
}


static void
data_imports_ui_concrete_dialog_pane_spit_data_imports_dialog_pane_interface_init (SpitDataImportsDialogPaneIface * iface)
{
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_concrete_dialog_pane_spit_data_imports_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	iface->get_widget = (GtkWidget* (*) (SpitDataImportsDialogPane *)) data_imports_ui_concrete_dialog_pane_real_get_widget;
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	iface->get_preferred_geometry = (SpitDataImportsDialogPaneGeometryOptions (*) (SpitDataImportsDialogPane *)) data_imports_ui_concrete_dialog_pane_real_get_preferred_geometry;
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	iface->on_pane_installed = (void (*) (SpitDataImportsDialogPane *)) data_imports_ui_concrete_dialog_pane_real_on_pane_installed;
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	iface->on_pane_uninstalled = (void (*) (SpitDataImportsDialogPane *)) data_imports_ui_concrete_dialog_pane_real_on_pane_uninstalled;
#line 500 "DataImportsUI.c"
}


static void
data_imports_ui_concrete_dialog_pane_instance_init (DataImportsUIConcreteDialogPane * self)
{
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv = DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE_GET_PRIVATE (self);
#line 509 "DataImportsUI.c"
}


static void
data_imports_ui_concrete_dialog_pane_finalize (GObject * obj)
{
	DataImportsUIConcreteDialogPane * self;
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPane);
#line 13 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	G_OBJECT_CLASS (data_imports_ui_concrete_dialog_pane_parent_class)->finalize (obj);
#line 523 "DataImportsUI.c"
}


GType
data_imports_ui_concrete_dialog_pane_get_type (void)
{
	static volatile gsize data_imports_ui_concrete_dialog_pane_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_ui_concrete_dialog_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsUIConcreteDialogPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_ui_concrete_dialog_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsUIConcreteDialogPane), 0, (GInstanceInitFunc) data_imports_ui_concrete_dialog_pane_instance_init, NULL };
		static const GInterfaceInfo spit_data_imports_dialog_pane_info = { (GInterfaceInitFunc) data_imports_ui_concrete_dialog_pane_spit_data_imports_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType data_imports_ui_concrete_dialog_pane_type_id;
		data_imports_ui_concrete_dialog_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsUIConcreteDialogPane", &g_define_type_info, 0);
		g_type_add_interface_static (data_imports_ui_concrete_dialog_pane_type_id, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, &spit_data_imports_dialog_pane_info);
		g_once_init_leave (&data_imports_ui_concrete_dialog_pane_type_id__volatile, data_imports_ui_concrete_dialog_pane_type_id);
	}
	return data_imports_ui_concrete_dialog_pane_type_id__volatile;
}


DataImportsUIStaticMessagePane*
data_imports_ui_static_message_pane_construct (GType object_type,
                                               const gchar* message_string)
{
	DataImportsUIStaticMessagePane * self = NULL;
	GtkLabel* message_label = NULL;
	GtkLabel* _tmp0_;
	GtkWidget* _tmp1_;
	GtkBox* _tmp2_;
	GtkBox* _tmp3_;
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (message_string != NULL, NULL);
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = (DataImportsUIStaticMessagePane*) data_imports_ui_concrete_dialog_pane_construct (object_type);
#line 36 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = (GtkLabel*) gtk_label_new (message_string);
#line 36 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp0_);
#line 36 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	message_label = _tmp0_;
#line 37 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = spit_data_imports_dialog_pane_get_widget (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 37 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, gtk_box_get_type ()) ? ((GtkBox*) _tmp1_) : NULL;
#line 37 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp2_ == NULL) {
#line 37 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_tmp1_);
#line 571 "DataImportsUI.c"
	}
#line 37 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = _tmp2_;
#line 37 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (_tmp3_, G_TYPE_CHECK_INSTANCE_CAST (message_label, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 37 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_tmp3_);
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (message_label);
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return self;
#line 583 "DataImportsUI.c"
}


DataImportsUIStaticMessagePane*
data_imports_ui_static_message_pane_new (const gchar* message_string)
{
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return data_imports_ui_static_message_pane_construct (DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE, message_string);
#line 592 "DataImportsUI.c"
}


DataImportsUIStaticMessagePane*
data_imports_ui_static_message_pane_construct_with_pango (GType object_type,
                                                          const gchar* msg)
{
	DataImportsUIStaticMessagePane * self = NULL;
	GtkLabel* label = NULL;
	GtkLabel* _tmp0_;
	GtkWidget* _tmp1_;
	GtkBox* _tmp2_;
	GtkBox* _tmp3_;
#line 40 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (msg != NULL, NULL);
#line 40 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = (DataImportsUIStaticMessagePane*) data_imports_ui_concrete_dialog_pane_construct (object_type);
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = (GtkLabel*) gtk_label_new (NULL);
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp0_);
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	label = _tmp0_;
#line 42 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_label_set_markup (label, msg);
#line 43 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_label_set_line_wrap (label, TRUE);
#line 45 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = spit_data_imports_dialog_pane_get_widget (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 45 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, gtk_box_get_type ()) ? ((GtkBox*) _tmp1_) : NULL;
#line 45 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp2_ == NULL) {
#line 45 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_tmp1_);
#line 628 "DataImportsUI.c"
	}
#line 45 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = _tmp2_;
#line 45 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (_tmp3_, G_TYPE_CHECK_INSTANCE_CAST (label, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 45 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_tmp3_);
#line 40 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (label);
#line 40 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return self;
#line 640 "DataImportsUI.c"
}


DataImportsUIStaticMessagePane*
data_imports_ui_static_message_pane_new_with_pango (const gchar* msg)
{
#line 40 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return data_imports_ui_static_message_pane_construct_with_pango (DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE, msg);
#line 649 "DataImportsUI.c"
}


static void
data_imports_ui_static_message_pane_class_init (DataImportsUIStaticMessagePaneClass * klass)
{
#line 34 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_static_message_pane_parent_class = g_type_class_peek_parent (klass);
#line 658 "DataImportsUI.c"
}


static void
data_imports_ui_static_message_pane_instance_init (DataImportsUIStaticMessagePane * self)
{
}


GType
data_imports_ui_static_message_pane_get_type (void)
{
	static volatile gsize data_imports_ui_static_message_pane_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_ui_static_message_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsUIStaticMessagePaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_ui_static_message_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsUIStaticMessagePane), 0, (GInstanceInitFunc) data_imports_ui_static_message_pane_instance_init, NULL };
		GType data_imports_ui_static_message_pane_type_id;
		data_imports_ui_static_message_pane_type_id = g_type_register_static (DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, "DataImportsUIStaticMessagePane", &g_define_type_info, 0);
		g_once_init_leave (&data_imports_ui_static_message_pane_type_id__volatile, data_imports_ui_static_message_pane_type_id);
	}
	return data_imports_ui_static_message_pane_type_id__volatile;
}


static Block11Data*
block11_data_ref (Block11Data* _data11_)
{
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_atomic_int_inc (&_data11_->_ref_count_);
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return _data11_;
#line 689 "DataImportsUI.c"
}


static void
block11_data_unref (void * _userdata_)
{
	Block11Data* _data11_;
	_data11_ = (Block11Data*) _userdata_;
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (g_atomic_int_dec_and_test (&_data11_->_ref_count_)) {
#line 700 "DataImportsUI.c"
		DataImportsUILibrarySelectionPane* self;
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		self = _data11_->self;
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_data11_->file_chooser);
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (self);
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_slice_free (Block11Data, _data11_);
#line 710 "DataImportsUI.c"
	}
}


static void
___lambda23_ (Block11Data* _data11_)
{
	DataImportsUILibrarySelectionPane* self;
	GtkFileChooserButton* _tmp0_;
	GFile* _tmp1_;
	GtkRadioButton* _tmp2_;
#line 101 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = _data11_->self;
#line 102 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = _data11_->file_chooser;
#line 102 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = gtk_file_chooser_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_file_chooser_get_type (), GtkFileChooser));
#line 102 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->selected_file);
#line 102 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->selected_file = _tmp1_;
#line 103 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = self->priv->file_radio;
#line 103 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp2_ != NULL) {
#line 736 "DataImportsUI.c"
		GtkRadioButton* _tmp3_;
#line 104 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp3_ = self->priv->file_radio;
#line 104 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 742 "DataImportsUI.c"
	}
#line 105 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_library_selection_pane_set_import_button_sensitivity (self);
#line 746 "DataImportsUI.c"
}


static void
____lambda23__gtk_file_chooser_selection_changed (GtkFileChooser* _sender,
                                                  gpointer self)
{
#line 101 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	___lambda23_ (self);
#line 756 "DataImportsUI.c"
}


static void
__lambda24_ (DataImportsUILibrarySelectionPane* self)
{
	SpitDataImportsImportableLibrary* _tmp0_;
#line 114 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->selected_library;
#line 114 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp0_ != NULL) {
#line 768 "DataImportsUI.c"
		SpitDataImportsImportableLibrary* _tmp1_;
#line 115 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp1_ = self->priv->selected_library;
#line 115 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_library_selection_pane_on_library_selected (self, _tmp1_);
#line 774 "DataImportsUI.c"
	} else {
		GFile* _tmp2_;
#line 116 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp2_ = self->priv->selected_file;
#line 116 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		if (_tmp2_ != NULL) {
#line 781 "DataImportsUI.c"
			GFile* _tmp3_;
#line 117 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp3_ = self->priv->selected_file;
#line 117 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			data_imports_ui_library_selection_pane_on_file_selected (self, _tmp3_);
#line 787 "DataImportsUI.c"
		} else {
#line 119 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			g_debug ("DataImportsUI.vala:119: LibrarySelectionPane: Library or file should b" \
"e selected.");
#line 791 "DataImportsUI.c"
		}
	}
}


static void
___lambda24__gtk_button_clicked (GtkButton* _sender,
                                 gpointer self)
{
#line 113 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	__lambda24_ ((DataImportsUILibrarySelectionPane*) self);
#line 803 "DataImportsUI.c"
}


DataImportsUILibrarySelectionPane*
data_imports_ui_library_selection_pane_construct (GType object_type,
                                                  SpitDataImportsPluginHost* host,
                                                  const gchar* welcome_message,
                                                  SpitDataImportsImportableLibrary** discovered_libraries,
                                                  int discovered_libraries_length1,
                                                  const gchar* file_select_label)
{
	DataImportsUILibrarySelectionPane * self = NULL;
	gboolean _tmp0_ = FALSE;
	GtkBox* content_box = NULL;
	GtkBox* _tmp1_;
	GtkBox* _tmp2_;
	GtkBox* _tmp3_;
	GtkLabel* welcome_label = NULL;
	GtkLabel* _tmp4_;
	GtkLabel* _tmp5_;
	GtkLabel* _tmp6_;
	GtkLabel* _tmp7_;
	GtkBox* _tmp8_;
	GtkLabel* _tmp9_;
	gint radio_margin_left = 0;
	gint radio_margin_right = 0;
	gint chooser_margin_left = 0;
	gint _tmp10_;
	gint chooser_margin_right = 0;
	gint _tmp11_;
	GtkRadioButton* lib_radio = NULL;
	GtkButton* _tmp38_;
	GtkButton* _tmp39_;
	GtkButtonBox* button_box = NULL;
	GtkButtonBox* _tmp40_;
	GtkButton* _tmp41_;
	GtkBox* _tmp42_;
	GtkWidget* _tmp43_;
	GtkBox* _tmp44_;
	GtkBox* _tmp45_;
	GtkBox* _tmp46_;
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (SPIT_DATA_IMPORTS_IS_PLUGIN_HOST (host), NULL);
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (welcome_message != NULL, NULL);
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = (DataImportsUILibrarySelectionPane*) data_imports_ui_concrete_dialog_pane_construct (object_type);
#line 62 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (discovered_libraries_length1 > 0) {
#line 62 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp0_ = TRUE;
#line 855 "DataImportsUI.c"
	} else {
#line 62 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp0_ = data_imports_ui_library_selection_pane_on_file_selected != NULL;
#line 859 "DataImportsUI.c"
	}
#line 62 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_vala_assert (_tmp0_, "discovered_libraries.length > 0 || on_file_selected != null");
#line 64 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->host = host;
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp1_);
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	content_box = _tmp1_;
#line 67 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = content_box;
#line 67 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_margin_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget), 30);
#line 68 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = content_box;
#line 68 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_margin_end (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), 30);
#line 69 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp4_ = (GtkLabel*) gtk_label_new (NULL);
#line 69 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp4_);
#line 69 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	welcome_label = _tmp4_;
#line 70 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp5_ = welcome_label;
#line 70 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_label_set_markup (_tmp5_, welcome_message);
#line 71 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp6_ = welcome_label;
#line 71 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_label_set_line_wrap (_tmp6_, TRUE);
#line 72 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp7_ = welcome_label;
#line 72 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_halign (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_START);
#line 73 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp8_ = content_box;
#line 73 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp9_ = welcome_label;
#line 73 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (_tmp8_, G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 6);
#line 76 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	radio_margin_left = 20;
#line 77 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	radio_margin_right = 20;
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp10_ = radio_margin_left;
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	chooser_margin_left = _tmp10_;
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp11_ = radio_margin_right;
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	chooser_margin_right = _tmp11_;
#line 81 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	lib_radio = NULL;
#line 82 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (discovered_libraries_length1 > 0) {
#line 919 "DataImportsUI.c"
		gint _tmp12_;
#line 83 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp12_ = radio_margin_left;
#line 83 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		chooser_margin_left = _tmp12_ + 20;
#line 925 "DataImportsUI.c"
		{
			SpitDataImportsImportableLibrary** library_collection = NULL;
			gint library_collection_length1 = 0;
			gint _library_collection_size_ = 0;
			gint library_it = 0;
#line 84 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			library_collection = discovered_libraries;
#line 84 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			library_collection_length1 = discovered_libraries_length1;
#line 84 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			for (library_it = 0; library_it < discovered_libraries_length1; library_it = library_it + 1) {
#line 937 "DataImportsUI.c"
				SpitDataImportsImportableLibrary* _tmp13_;
				SpitDataImportsImportableLibrary* library = NULL;
#line 84 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				_tmp13_ = _g_object_ref0 (library_collection[library_it]);
#line 84 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				library = _tmp13_;
#line 944 "DataImportsUI.c"
				{
					gchar* lib_radio_label = NULL;
					SpitDataImportsImportableLibrary* _tmp14_;
					gchar* _tmp15_;
					GtkBox* _tmp16_;
					GtkRadioButton* _tmp17_;
					SpitDataImportsImportableLibrary* _tmp18_;
					const gchar* _tmp19_;
					gint _tmp20_;
					gint _tmp21_;
					GtkRadioButton* _tmp22_;
#line 85 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp14_ = library;
#line 85 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp15_ = spit_data_imports_importable_library_get_display_name (_tmp14_);
#line 85 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					lib_radio_label = _tmp15_;
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp16_ = content_box;
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp17_ = lib_radio;
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp18_ = library;
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp19_ = lib_radio_label;
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp20_ = radio_margin_left;
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp21_ = radio_margin_right;
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp22_ = data_imports_ui_library_selection_pane_create_radio_button (self, _tmp16_, _tmp17_, _tmp18_, _tmp19_, _tmp20_, _tmp21_);
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_g_object_unref0 (lib_radio);
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					lib_radio = _tmp22_;
#line 84 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_g_free0 (lib_radio_label);
#line 84 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_g_object_unref0 (library);
#line 984 "DataImportsUI.c"
				}
			}
		}
#line 91 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		if (file_select_label != NULL) {
#line 990 "DataImportsUI.c"
			GtkBox* _tmp23_;
			GtkRadioButton* _tmp24_;
			gint _tmp25_;
			gint _tmp26_;
			GtkRadioButton* _tmp27_;
			GtkRadioButton* _tmp28_;
			GtkRadioButton* _tmp29_;
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp23_ = content_box;
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp24_ = lib_radio;
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp25_ = radio_margin_left;
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp26_ = radio_margin_right;
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp27_ = data_imports_ui_library_selection_pane_create_radio_button (self, _tmp23_, _tmp24_, NULL, file_select_label, _tmp25_, _tmp26_);
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_g_object_unref0 (lib_radio);
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			lib_radio = _tmp27_;
#line 96 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp28_ = lib_radio;
#line 96 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp29_ = _g_object_ref0 (_tmp28_);
#line 96 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_g_object_unref0 (self->priv->file_radio);
#line 96 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			self->priv->file_radio = _tmp29_;
#line 1020 "DataImportsUI.c"
		}
	}
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (file_select_label != NULL) {
#line 1025 "DataImportsUI.c"
		Block11Data* _data11_;
		GtkFileChooserButton* _tmp30_;
		GtkFileChooserButton* _tmp31_;
		GtkFileChooserButton* _tmp32_;
		gint _tmp33_;
		GtkFileChooserButton* _tmp34_;
		gint _tmp35_;
		GtkBox* _tmp36_;
		GtkFileChooserButton* _tmp37_;
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_data11_ = g_slice_new0 (Block11Data);
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_data11_->_ref_count_ = 1;
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_data11_->self = g_object_ref (self);
#line 100 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp30_ = (GtkFileChooserButton*) gtk_file_chooser_button_new (_ ("Database file:"), GTK_FILE_CHOOSER_ACTION_OPEN);
#line 100 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_object_ref_sink (_tmp30_);
#line 100 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_data11_->file_chooser = _tmp30_;
#line 101 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp31_ = _data11_->file_chooser;
#line 101 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_signal_connect_data (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, gtk_file_chooser_get_type (), GtkFileChooser), "selection-changed", (GCallback) ____lambda23__gtk_file_chooser_selection_changed, block11_data_ref (_data11_), (GClosureNotify) block11_data_unref, 0);
#line 107 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp32_ = _data11_->file_chooser;
#line 107 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp33_ = chooser_margin_left;
#line 107 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_widget_set_margin_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_widget_get_type (), GtkWidget), _tmp33_);
#line 108 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp34_ = _data11_->file_chooser;
#line 108 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp35_ = chooser_margin_right;
#line 108 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_widget_set_margin_end (G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, gtk_widget_get_type (), GtkWidget), _tmp35_);
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp36_ = content_box;
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp37_ = _data11_->file_chooser;
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_box_pack_start (_tmp36_, G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 6);
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		block11_data_unref (_data11_);
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_data11_ = NULL;
#line 1073 "DataImportsUI.c"
	}
#line 112 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp38_ = (GtkButton*) gtk_button_new_with_mnemonic (_ ("_Import"));
#line 112 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp38_);
#line 112 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->import_button);
#line 112 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->import_button = _tmp38_;
#line 113 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp39_ = self->priv->import_button;
#line 113 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_signal_connect_object (_tmp39_, "clicked", (GCallback) ___lambda24__gtk_button_clicked, self, 0);
#line 121 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp40_ = (GtkButtonBox*) gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
#line 121 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp40_);
#line 121 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	button_box = _tmp40_;
#line 122 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_set (button_box, "layout-style", GTK_BUTTONBOX_CENTER, NULL);
#line 123 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp41_ = self->priv->import_button;
#line 123 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (button_box, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, gtk_widget_get_type (), GtkWidget));
#line 124 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp42_ = content_box;
#line 124 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_end (_tmp42_, G_TYPE_CHECK_INSTANCE_CAST (button_box, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 6);
#line 126 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp43_ = spit_data_imports_dialog_pane_get_widget (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 126 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp44_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp43_, gtk_box_get_type ()) ? ((GtkBox*) _tmp43_) : NULL;
#line 126 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp44_ == NULL) {
#line 126 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_tmp43_);
#line 1111 "DataImportsUI.c"
	}
#line 126 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp45_ = _tmp44_;
#line 126 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp46_ = content_box;
#line 126 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (_tmp45_, G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 126 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_tmp45_);
#line 128 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_library_selection_pane_set_import_button_sensitivity (self);
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (button_box);
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (lib_radio);
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (welcome_label);
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (content_box);
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return self;
#line 1133 "DataImportsUI.c"
}


DataImportsUILibrarySelectionPane*
data_imports_ui_library_selection_pane_new (SpitDataImportsPluginHost* host,
                                            const gchar* welcome_message,
                                            SpitDataImportsImportableLibrary** discovered_libraries,
                                            int discovered_libraries_length1,
                                            const gchar* file_select_label)
{
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return data_imports_ui_library_selection_pane_construct (DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, host, welcome_message, discovered_libraries, discovered_libraries_length1, file_select_label);
#line 1146 "DataImportsUI.c"
}


static Block12Data*
block12_data_ref (Block12Data* _data12_)
{
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_atomic_int_inc (&_data12_->_ref_count_);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return _data12_;
#line 1157 "DataImportsUI.c"
}


static void
block12_data_unref (void * _userdata_)
{
	Block12Data* _data12_;
	_data12_ = (Block12Data*) _userdata_;
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (g_atomic_int_dec_and_test (&_data12_->_ref_count_)) {
#line 1168 "DataImportsUI.c"
		DataImportsUILibrarySelectionPane* self;
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		self = _data12_->self;
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_data12_->button);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_data12_->library);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (self);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_slice_free (Block12Data, _data12_);
#line 1180 "DataImportsUI.c"
	}
}


static void
__lambda22_ (Block12Data* _data12_)
{
	DataImportsUILibrarySelectionPane* self;
	GtkRadioButton* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 140 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = _data12_->self;
#line 141 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = _data12_->button;
#line 141 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 141 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = _tmp1_;
#line 141 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp2_) {
#line 1202 "DataImportsUI.c"
		SpitDataImportsImportableLibrary* _tmp3_;
#line 142 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp3_ = _g_object_ref0 (_data12_->library);
#line 142 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (self->priv->selected_library);
#line 142 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		self->priv->selected_library = _tmp3_;
#line 143 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_library_selection_pane_set_import_button_sensitivity (self);
#line 1212 "DataImportsUI.c"
	}
}


static void
___lambda22__gtk_toggle_button_toggled (GtkToggleButton* _sender,
                                        gpointer self)
{
#line 140 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	__lambda22_ (self);
#line 1223 "DataImportsUI.c"
}


static GtkRadioButton*
data_imports_ui_library_selection_pane_create_radio_button (DataImportsUILibrarySelectionPane* self,
                                                            GtkBox* box,
                                                            GtkRadioButton* group,
                                                            SpitDataImportsImportableLibrary* library,
                                                            const gchar* label,
                                                            gint margin_left,
                                                            gint margin_right)
{
	GtkRadioButton* result = NULL;
	Block12Data* _data12_;
	SpitDataImportsImportableLibrary* _tmp0_;
	GtkRadioButton* _tmp1_;
	GtkRadioButton* _tmp4_;
	GtkRadioButton* _tmp5_;
	GtkRadioButton* _tmp6_;
	GtkRadioButton* _tmp7_;
	GtkRadioButton* _tmp8_;
	GtkRadioButton* _tmp9_;
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (DATA_IMPORTS_UI_IS_LIBRARY_SELECTION_PANE (self), NULL);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (GTK_IS_BOX (box), NULL);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail ((group == NULL) || GTK_IS_RADIO_BUTTON (group), NULL);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail ((library == NULL) || SPIT_DATA_IMPORTS_IS_IMPORTABLE_LIBRARY (library), NULL);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (label != NULL, NULL);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_data12_ = g_slice_new0 (Block12Data);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_data12_->_ref_count_ = 1;
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_data12_->self = g_object_ref (self);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = _g_object_ref0 (library);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_data12_->library);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_data12_->library = _tmp0_;
#line 135 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = (GtkRadioButton*) gtk_radio_button_new_with_label_from_widget (group, label);
#line 135 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp1_);
#line 135 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_data12_->button = _tmp1_;
#line 136 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (group == NULL) {
#line 1276 "DataImportsUI.c"
		GtkRadioButton* _tmp2_;
		SpitDataImportsImportableLibrary* _tmp3_;
#line 137 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp2_ = _data12_->button;
#line 137 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 138 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp3_ = _g_object_ref0 (_data12_->library);
#line 138 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (self->priv->selected_library);
#line 138 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		self->priv->selected_library = _tmp3_;
#line 1289 "DataImportsUI.c"
	}
#line 140 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp4_ = _data12_->button;
#line 140 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_signal_connect_data (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_toggle_button_get_type (), GtkToggleButton), "toggled", (GCallback) ___lambda22__gtk_toggle_button_toggled, block12_data_ref (_data12_), (GClosureNotify) block12_data_unref, 0);
#line 147 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp5_ = _data12_->button;
#line 147 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_margin_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget), margin_left);
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp6_ = _data12_->button;
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_margin_end (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_widget_get_type (), GtkWidget), margin_right);
#line 149 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp7_ = _data12_->button;
#line 149 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (box, G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 6);
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp8_ = _data12_->button;
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp9_ = _g_object_ref0 (_tmp8_);
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	result = _tmp9_;
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	block12_data_unref (_data12_);
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_data12_ = NULL;
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return result;
#line 1319 "DataImportsUI.c"
}


static void
data_imports_ui_library_selection_pane_set_import_button_sensitivity (DataImportsUILibrarySelectionPane* self)
{
	gboolean _tmp0_ = FALSE;
	SpitDataImportsImportableLibrary* _tmp1_;
	GtkButton* _tmp3_;
#line 153 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_LIBRARY_SELECTION_PANE (self));
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = self->priv->selected_library;
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp1_ != NULL) {
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp0_ = TRUE;
#line 1337 "DataImportsUI.c"
	} else {
		GFile* _tmp2_;
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp2_ = self->priv->selected_file;
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp0_ = _tmp2_ != NULL;
#line 1344 "DataImportsUI.c"
	}
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = self->priv->import_button;
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), _tmp0_);
#line 1350 "DataImportsUI.c"
}


static void
data_imports_ui_library_selection_pane_on_library_selected (DataImportsUILibrarySelectionPane* self,
                                                            SpitDataImportsImportableLibrary* library)
{
	SpitDataImportsPluginHost* _tmp0_;
	SpitDataImportsDataImporter* _tmp1_;
	SpitDataImportsDataImporter* _tmp2_;
#line 157 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_LIBRARY_SELECTION_PANE (self));
#line 157 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_IMPORTABLE_LIBRARY (library));
#line 158 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->host;
#line 158 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = spit_data_imports_plugin_host_get_data_importer (_tmp0_);
#line 158 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = _tmp1_;
#line 158 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	spit_data_imports_data_importer_on_library_selected (_tmp2_, library);
#line 158 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_tmp2_);
#line 1375 "DataImportsUI.c"
}


static void
data_imports_ui_library_selection_pane_on_file_selected (DataImportsUILibrarySelectionPane* self,
                                                         GFile* file)
{
	SpitDataImportsPluginHost* _tmp0_;
	SpitDataImportsDataImporter* _tmp1_;
	SpitDataImportsDataImporter* _tmp2_;
#line 161 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_LIBRARY_SELECTION_PANE (self));
#line 161 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (G_IS_FILE (file));
#line 162 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->host;
#line 162 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = spit_data_imports_plugin_host_get_data_importer (_tmp0_);
#line 162 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = _tmp1_;
#line 162 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	spit_data_imports_data_importer_on_file_selected (_tmp2_, file);
#line 162 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_tmp2_);
#line 1400 "DataImportsUI.c"
}


static void
data_imports_ui_library_selection_pane_class_init (DataImportsUILibrarySelectionPaneClass * klass)
{
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_library_selection_pane_parent_class = g_type_class_peek_parent (klass);
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_type_class_add_private (klass, sizeof (DataImportsUILibrarySelectionPanePrivate));
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_ui_library_selection_pane_finalize;
#line 1413 "DataImportsUI.c"
}


static void
data_imports_ui_library_selection_pane_instance_init (DataImportsUILibrarySelectionPane * self)
{
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv = DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE_GET_PRIVATE (self);
#line 51 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->selected_library = NULL;
#line 52 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->selected_file = NULL;
#line 54 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->file_radio = NULL;
#line 1428 "DataImportsUI.c"
}


static void
data_imports_ui_library_selection_pane_finalize (GObject * obj)
{
	DataImportsUILibrarySelectionPane * self;
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, DataImportsUILibrarySelectionPane);
#line 51 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->selected_library);
#line 52 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->selected_file);
#line 53 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->import_button);
#line 54 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->file_radio);
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	G_OBJECT_CLASS (data_imports_ui_library_selection_pane_parent_class)->finalize (obj);
#line 1448 "DataImportsUI.c"
}


GType
data_imports_ui_library_selection_pane_get_type (void)
{
	static volatile gsize data_imports_ui_library_selection_pane_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_ui_library_selection_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsUILibrarySelectionPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_ui_library_selection_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsUILibrarySelectionPane), 0, (GInstanceInitFunc) data_imports_ui_library_selection_pane_instance_init, NULL };
		GType data_imports_ui_library_selection_pane_type_id;
		data_imports_ui_library_selection_pane_type_id = g_type_register_static (DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, "DataImportsUILibrarySelectionPane", &g_define_type_info, 0);
		g_once_init_leave (&data_imports_ui_library_selection_pane_type_id__volatile, data_imports_ui_library_selection_pane_type_id);
	}
	return data_imports_ui_library_selection_pane_type_id__volatile;
}


DataImportsUIProgressPane*
data_imports_ui_progress_pane_construct (GType object_type,
                                         const gchar* message)
{
	DataImportsUIProgressPane * self = NULL;
	GtkBox* content_box = NULL;
	GtkBox* _tmp0_;
	GtkLabel* _tmp1_;
	GtkLabel* _tmp2_;
	GtkProgressBar* _tmp3_;
	GtkProgressBar* _tmp4_;
	GtkLabel* _tmp5_;
	GtkLabel* _tmp6_;
	GtkWidget* _tmp7_;
	GtkContainer* _tmp8_;
	GtkContainer* _tmp9_;
#line 171 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (message != NULL, NULL);
#line 171 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = (DataImportsUIProgressPane*) data_imports_ui_concrete_dialog_pane_construct (object_type);
#line 172 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
#line 172 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp0_);
#line 172 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	content_box = _tmp0_;
#line 173 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = (GtkLabel*) gtk_label_new (message);
#line 173 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp1_);
#line 173 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->message_label);
#line 173 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->message_label = _tmp1_;
#line 174 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = self->priv->message_label;
#line 174 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (content_box, G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 6);
#line 175 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = (GtkProgressBar*) gtk_progress_bar_new ();
#line 175 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp3_);
#line 175 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->progress_bar);
#line 175 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->progress_bar = _tmp3_;
#line 176 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp4_ = self->priv->progress_bar;
#line 176 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (content_box, G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_widget_get_type (), GtkWidget), FALSE, TRUE, (guint) 6);
#line 177 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp5_ = (GtkLabel*) gtk_label_new ("");
#line 177 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp5_);
#line 177 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->progress_label);
#line 177 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->progress_label = _tmp5_;
#line 178 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp6_ = self->priv->progress_label;
#line 178 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (content_box, G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_widget_get_type (), GtkWidget), FALSE, TRUE, (guint) 6);
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp7_ = spit_data_imports_dialog_pane_get_widget (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp8_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, gtk_container_get_type ()) ? ((GtkContainer*) _tmp7_) : NULL;
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp8_ == NULL) {
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_tmp7_);
#line 1536 "DataImportsUI.c"
	}
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp9_ = _tmp8_;
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_container_add (_tmp9_, G_TYPE_CHECK_INSTANCE_CAST (content_box, gtk_widget_get_type (), GtkWidget));
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_tmp9_);
#line 171 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (content_box);
#line 171 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return self;
#line 1548 "DataImportsUI.c"
}


DataImportsUIProgressPane*
data_imports_ui_progress_pane_new (const gchar* message)
{
#line 171 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return data_imports_ui_progress_pane_construct (DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, message);
#line 1557 "DataImportsUI.c"
}


void
data_imports_ui_progress_pane_update_progress (DataImportsUIProgressPane* self,
                                               gdouble progress,
                                               const gchar* progress_message)
{
	GtkProgressBar* _tmp0_;
#line 183 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_PROGRESS_PANE (self));
#line 184 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->progress_bar;
#line 184 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_progress_bar_set_fraction (_tmp0_, progress);
#line 185 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (progress_message != NULL) {
#line 1575 "DataImportsUI.c"
		GtkLabel* _tmp1_;
#line 186 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp1_ = self->priv->progress_label;
#line 186 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_label_set_label (_tmp1_, progress_message);
#line 1581 "DataImportsUI.c"
	}
#line 187 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	spin_event_loop ();
#line 1585 "DataImportsUI.c"
}


static void
data_imports_ui_progress_pane_class_init (DataImportsUIProgressPaneClass * klass)
{
#line 166 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_progress_pane_parent_class = g_type_class_peek_parent (klass);
#line 166 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_type_class_add_private (klass, sizeof (DataImportsUIProgressPanePrivate));
#line 166 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_ui_progress_pane_finalize;
#line 1598 "DataImportsUI.c"
}


static void
data_imports_ui_progress_pane_instance_init (DataImportsUIProgressPane * self)
{
#line 166 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv = DATA_IMPORTS_UI_PROGRESS_PANE_GET_PRIVATE (self);
#line 1607 "DataImportsUI.c"
}


static void
data_imports_ui_progress_pane_finalize (GObject * obj)
{
	DataImportsUIProgressPane * self;
#line 166 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, DataImportsUIProgressPane);
#line 167 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->message_label);
#line 168 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->progress_label);
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->progress_bar);
#line 166 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	G_OBJECT_CLASS (data_imports_ui_progress_pane_parent_class)->finalize (obj);
#line 1625 "DataImportsUI.c"
}


GType
data_imports_ui_progress_pane_get_type (void)
{
	static volatile gsize data_imports_ui_progress_pane_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_ui_progress_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsUIProgressPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_ui_progress_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsUIProgressPane), 0, (GInstanceInitFunc) data_imports_ui_progress_pane_instance_init, NULL };
		GType data_imports_ui_progress_pane_type_id;
		data_imports_ui_progress_pane_type_id = g_type_register_static (DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, "DataImportsUIProgressPane", &g_define_type_info, 0);
		g_once_init_leave (&data_imports_ui_progress_pane_type_id__volatile, data_imports_ui_progress_pane_type_id);
	}
	return data_imports_ui_progress_pane_type_id__volatile;
}


static gboolean
_data_imports_ui_data_imports_dialog_on_window_close_gtk_widget_delete_event (GtkWidget* _sender,
                                                                              GdkEventAny* event,
                                                                              gpointer self)
{
	gboolean result;
	result = data_imports_ui_data_imports_dialog_on_window_close ((DataImportsUIDataImportsDialog*) self, event);
#line 217 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return result;
#line 1652 "DataImportsUI.c"
}


static void
_data_imports_ui_data_imports_dialog_on_service_changed_gtk_combo_box_changed (GtkComboBox* _sender,
                                                                               gpointer self)
{
#line 250 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_data_imports_dialog_on_service_changed ((DataImportsUIDataImportsDialog*) self);
#line 1662 "DataImportsUI.c"
}


static void
_data_imports_ui_data_imports_dialog_on_close_cancel_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                 gpointer self)
{
#line 305 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_data_imports_dialog_on_close_cancel_clicked ((DataImportsUIDataImportsDialog*) self);
#line 1672 "DataImportsUI.c"
}


DataImportsUIDataImportsDialog*
data_imports_ui_data_imports_dialog_construct (GType object_type)
{
	DataImportsUIDataImportsDialog * self = NULL;
	gboolean use_header = FALSE;
	gboolean _tmp0_;
	gchar* title = NULL;
	gchar* _tmp2_;
	gchar* label = NULL;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	SpitDataImportsService** loaded_services = NULL;
	gint _tmp5_;
	SpitDataImportsService** _tmp6_;
	gint loaded_services_length1;
	gint _loaded_services_size_;
	SpitDataImportsService** _tmp7_;
	gint _tmp7__length1;
	GtkBox* _tmp62_;
	GtkBox* _tmp63_;
	GtkBox* _tmp64_;
	gboolean _tmp65_;
	GtkButton* _tmp75_;
	SpitDataImportsService** _tmp76_;
	gint _tmp76__length1;
#line 211 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	use_header = resources_use_header_bar () == 1;
#line 212 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = (DataImportsUIDataImportsDialog*) g_object_new (object_type, "use-header-bar", resources_use_header_bar (), NULL);
#line 213 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = use_header;
#line 213 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp0_) {
#line 1709 "DataImportsUI.c"
		GtkWidget* _tmp1_;
#line 214 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp1_ = gtk_dialog_get_header_bar (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 214 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_header_bar_set_show_close_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_header_bar_get_type (), GtkHeaderBar), FALSE);
#line 1715 "DataImportsUI.c"
	}
#line 216 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 217 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "delete-event", (GCallback) _data_imports_ui_data_imports_dialog_on_window_close_gtk_widget_delete_event, self, 0);
#line 219 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = g_strdup (_ ("Import From Application"));
#line 219 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	title = _tmp2_;
#line 220 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = g_strdup (_ ("Import media _from:"));
#line 220 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	label = _tmp3_;
#line 222 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp4_ = title;
#line 222 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp4_);
#line 224 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp6_ = spit_data_imports_load_services (FALSE, &_tmp5_);
#line 224 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	loaded_services = _tmp6_;
#line 224 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	loaded_services_length1 = _tmp5_;
#line 224 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_loaded_services_size_ = loaded_services_length1;
#line 226 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp7_ = loaded_services;
#line 226 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp7__length1 = loaded_services_length1;
#line 226 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp7__length1 > 0) {
#line 1747 "DataImportsUI.c"
		GtkComboBoxText* _tmp8_;
		GtkComboBoxText* _tmp9_;
		gchar* last_used_service = NULL;
		ConfigFacade* _tmp10_;
		ConfigFacade* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gint ticker = 0;
		gint last_used_index = 0;
		SpitDataImportsService** _tmp14_;
		gint _tmp14__length1;
		gint _tmp28_;
		GtkComboBoxText* _tmp32_;
		gboolean _tmp33_;
#line 229 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp8_ = (GtkComboBoxText*) gtk_combo_box_text_new ();
#line 229 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_object_ref_sink (_tmp8_);
#line 229 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (self->priv->service_selector_box);
#line 229 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		self->priv->service_selector_box = _tmp8_;
#line 230 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp9_ = self->priv->service_selector_box;
#line 230 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 233 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp10_ = config_facade_get_instance ();
#line 233 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp11_ = _tmp10_;
#line 233 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp12_ = configuration_facade_get_last_used_dataimports_service (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 233 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp13_ = _tmp12_;
#line 233 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_tmp11_);
#line 233 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		last_used_service = _tmp13_;
#line 235 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		ticker = 0;
#line 236 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		last_used_index = -1;
#line 237 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp14_ = loaded_services;
#line 237 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp14__length1 = loaded_services_length1;
#line 1794 "DataImportsUI.c"
		{
			SpitDataImportsService** service_collection = NULL;
			gint service_collection_length1 = 0;
			gint _service_collection_size_ = 0;
			gint service_it = 0;
#line 237 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			service_collection = _tmp14_;
#line 237 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			service_collection_length1 = _tmp14__length1;
#line 237 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			for (service_it = 0; service_it < _tmp14__length1; service_it = service_it + 1) {
#line 1806 "DataImportsUI.c"
				SpitDataImportsService* _tmp15_;
				SpitDataImportsService* service = NULL;
#line 237 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				_tmp15_ = _g_object_ref0 (service_collection[service_it]);
#line 237 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				service = _tmp15_;
#line 1813 "DataImportsUI.c"
				{
					gchar* curr_service_id = NULL;
					SpitDataImportsService* _tmp16_;
					const gchar* _tmp17_;
					gchar* _tmp18_;
					gboolean _tmp19_ = FALSE;
					const gchar* _tmp20_;
					GtkComboBoxText* _tmp24_;
					SpitDataImportsService* _tmp25_;
					const gchar* _tmp26_;
					gint _tmp27_;
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp16_ = service;
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp17_ = spit_pluggable_get_id (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp18_ = g_strdup (_tmp17_);
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					curr_service_id = _tmp18_;
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp20_ = last_used_service;
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					if (_tmp20_ != NULL) {
#line 1837 "DataImportsUI.c"
						const gchar* _tmp21_;
						const gchar* _tmp22_;
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
						_tmp21_ = last_used_service;
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
						_tmp22_ = curr_service_id;
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
						_tmp19_ = g_strcmp0 (_tmp21_, _tmp22_) == 0;
#line 1846 "DataImportsUI.c"
					} else {
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
						_tmp19_ = FALSE;
#line 1850 "DataImportsUI.c"
					}
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					if (_tmp19_) {
#line 1854 "DataImportsUI.c"
						gint _tmp23_;
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
						_tmp23_ = ticker;
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
						last_used_index = _tmp23_;
#line 1860 "DataImportsUI.c"
					}
#line 242 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp24_ = self->priv->service_selector_box;
#line 242 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp25_ = service;
#line 242 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp26_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 242 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					gtk_combo_box_text_append_text (_tmp24_, _tmp26_);
#line 243 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp27_ = ticker;
#line 243 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					ticker = _tmp27_ + 1;
#line 237 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_g_free0 (curr_service_id);
#line 237 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_g_object_unref0 (service);
#line 1878 "DataImportsUI.c"
				}
			}
		}
#line 245 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp28_ = last_used_index;
#line 245 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		if (_tmp28_ >= 0) {
#line 1886 "DataImportsUI.c"
			GtkComboBoxText* _tmp29_;
			gint _tmp30_;
#line 246 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp29_ = self->priv->service_selector_box;
#line 246 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp30_ = last_used_index;
#line 246 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, gtk_combo_box_get_type (), GtkComboBox), _tmp30_);
#line 1895 "DataImportsUI.c"
		} else {
			GtkComboBoxText* _tmp31_;
#line 248 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp31_ = self->priv->service_selector_box;
#line 248 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 1902 "DataImportsUI.c"
		}
#line 250 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp32_ = self->priv->service_selector_box;
#line 250 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _data_imports_ui_data_imports_dialog_on_service_changed_gtk_combo_box_changed, self, 0);
#line 252 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp33_ = use_header;
#line 252 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		if (!_tmp33_) {
#line 1912 "DataImportsUI.c"
			GtkLabel* service_selector_box_label = NULL;
			const gchar* _tmp34_;
			GtkLabel* _tmp35_;
			GtkLabel* _tmp36_;
			GtkComboBoxText* _tmp37_;
			GtkLabel* _tmp38_;
			GtkLabel* _tmp39_;
			GtkComboBoxText* _tmp40_;
			GtkComboBoxText* _tmp41_;
			GtkComboBoxText* _tmp42_;
			GtkComboBoxText* _tmp43_;
			GtkBox* service_selector_layouter = NULL;
			GtkBox* _tmp44_;
			GtkBox* _tmp45_;
			GtkBox* _tmp46_;
			GtkLabel* _tmp47_;
			GtkBox* _tmp48_;
			GtkComboBoxText* _tmp49_;
			GtkBox* service_area_layouter = NULL;
			GtkBox* _tmp50_;
			GtkBox* _tmp51_;
			GtkBox* _tmp52_;
			GtkSeparator* service_central_separator = NULL;
			GtkSeparator* _tmp53_;
			GtkBox* _tmp54_;
			GtkSeparator* _tmp55_;
			GtkBox* _tmp56_;
			GtkBox* _tmp57_;
			GtkBox* _tmp58_;
			GtkBox* _tmp59_;
			GtkBox* _tmp60_;
			GtkBox* _tmp61_;
#line 254 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp34_ = label;
#line 254 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp35_ = (GtkLabel*) gtk_label_new_with_mnemonic (_tmp34_);
#line 254 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			g_object_ref_sink (_tmp35_);
#line 254 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			service_selector_box_label = _tmp35_;
#line 255 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp36_ = service_selector_box_label;
#line 255 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp37_ = self->priv->service_selector_box;
#line 255 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_label_set_mnemonic_widget (_tmp36_, G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, gtk_widget_get_type (), GtkWidget));
#line 256 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp38_ = service_selector_box_label;
#line 256 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_widget_set_halign (G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_START);
#line 257 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp39_ = service_selector_box_label;
#line 257 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_widget_set_valign (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_CENTER);
#line 263 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp40_ = self->priv->service_selector_box;
#line 263 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_widget_set_halign (G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_END);
#line 264 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp41_ = self->priv->service_selector_box;
#line 264 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_widget_set_valign (G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_CENTER);
#line 265 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp42_ = self->priv->service_selector_box;
#line 265 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_widget_set_hexpand (G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 266 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp43_ = self->priv->service_selector_box;
#line 266 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_widget_set_vexpand (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 268 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp44_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
#line 268 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			g_object_ref_sink (_tmp44_);
#line 268 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			service_selector_layouter = _tmp44_;
#line 269 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp45_ = service_selector_layouter;
#line 269 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_container_set_border_width (G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, gtk_container_get_type (), GtkContainer), (guint) 12);
#line 270 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp46_ = service_selector_layouter;
#line 270 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp47_ = service_selector_box_label;
#line 270 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp47_, gtk_widget_get_type (), GtkWidget));
#line 271 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp48_ = service_selector_layouter;
#line 271 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp49_ = self->priv->service_selector_box;
#line 271 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_box_pack_start (_tmp48_, G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 275 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp50_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 275 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			g_object_ref_sink (_tmp50_);
#line 275 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			service_area_layouter = _tmp50_;
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp51_ = service_area_layouter;
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp52_ = service_selector_layouter;
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_box_pack_start (_tmp51_, G_TYPE_CHECK_INSTANCE_CAST (_tmp52_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 277 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp53_ = (GtkSeparator*) gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
#line 277 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			g_object_ref_sink (_tmp53_);
#line 277 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			service_central_separator = _tmp53_;
#line 278 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp54_ = service_area_layouter;
#line 278 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp55_ = service_central_separator;
#line 278 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp54_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, gtk_widget_get_type (), GtkWidget));
#line 279 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp56_ = service_area_layouter;
#line 279 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_widget_set_halign (G_TYPE_CHECK_INSTANCE_CAST (_tmp56_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_FILL);
#line 280 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp57_ = service_area_layouter;
#line 280 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_widget_set_valign (G_TYPE_CHECK_INSTANCE_CAST (_tmp57_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_START);
#line 281 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp58_ = service_area_layouter;
#line 281 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_widget_set_hexpand (G_TYPE_CHECK_INSTANCE_CAST (_tmp58_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 282 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp59_ = service_area_layouter;
#line 282 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_widget_set_vexpand (G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 284 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp60_ = gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 284 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp61_ = service_area_layouter;
#line 284 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_box_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp60_, gtk_box_get_type (), GtkBox), G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 252 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_g_object_unref0 (service_central_separator);
#line 252 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_g_object_unref0 (service_area_layouter);
#line 252 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_g_object_unref0 (service_selector_layouter);
#line 252 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_g_object_unref0 (service_selector_box_label);
#line 2059 "DataImportsUI.c"
		}
#line 226 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_free0 (last_used_service);
#line 2063 "DataImportsUI.c"
	}
#line 289 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp62_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 289 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp62_);
#line 289 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->central_area_layouter);
#line 289 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->central_area_layouter = _tmp62_;
#line 290 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp63_ = gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 290 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp64_ = self->priv->central_area_layouter;
#line 290 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp63_, gtk_box_get_type (), GtkBox), G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 293 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp65_ = use_header;
#line 293 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp65_) {
#line 2083 "DataImportsUI.c"
		GtkButton* _tmp66_;
		GtkButton* _tmp67_;
		GtkWidget* _tmp68_;
		GtkButton* _tmp69_;
		GtkComboBoxText* _tmp70_;
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp66_ = (GtkButton*) gtk_button_new_with_mnemonic ("_Cancel");
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_object_ref_sink (_tmp66_);
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (self->priv->close_cancel_button);
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		self->priv->close_cancel_button = _tmp66_;
#line 295 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp67_ = self->priv->close_cancel_button;
#line 295 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_widget_set_can_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp67_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 296 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp68_ = gtk_dialog_get_header_bar (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 296 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp69_ = self->priv->close_cancel_button;
#line 296 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_header_bar_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, gtk_header_bar_get_type (), GtkHeaderBar), G_TYPE_CHECK_INSTANCE_CAST (_tmp69_, gtk_widget_get_type (), GtkWidget));
#line 297 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp70_ = self->priv->service_selector_box;
#line 297 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		if (_tmp70_ != NULL) {
#line 2111 "DataImportsUI.c"
			GtkWidget* _tmp71_;
			GtkComboBoxText* _tmp72_;
#line 298 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp71_ = gtk_dialog_get_header_bar (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 298 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp72_ = self->priv->service_selector_box;
#line 298 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_header_bar_pack_end (G_TYPE_CHECK_INSTANCE_CAST (_tmp71_, gtk_header_bar_get_type (), GtkHeaderBar), G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, gtk_widget_get_type (), GtkWidget));
#line 2120 "DataImportsUI.c"
		}
	} else {
		GtkWidget* _tmp73_;
		GtkButton* _tmp74_;
#line 302 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), _ ("_Cancel"), (gint) GTK_RESPONSE_CANCEL);
#line 303 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp73_ = gtk_dialog_get_widget_for_response (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_CANCEL);
#line 303 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp74_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp73_, gtk_button_get_type ()) ? ((GtkButton*) _tmp73_) : NULL);
#line 303 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (self->priv->close_cancel_button);
#line 303 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		self->priv->close_cancel_button = _tmp74_;
#line 2135 "DataImportsUI.c"
	}
#line 305 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp75_ = self->priv->close_cancel_button;
#line 305 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_signal_connect_object (_tmp75_, "clicked", (GCallback) _data_imports_ui_data_imports_dialog_on_close_cancel_clicked_gtk_button_clicked, self, 0);
#line 307 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_data_imports_dialog_set_standard_window_mode (self);
#line 309 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp76_ = loaded_services;
#line 309 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp76__length1 = loaded_services_length1;
#line 309 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp76__length1 > 0) {
#line 311 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_data_imports_dialog_on_service_changed (self);
#line 2151 "DataImportsUI.c"
	} else {
		DataImportsUIStaticMessagePane* _tmp77_;
		DataImportsUIStaticMessagePane* _tmp78_;
#line 314 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp77_ = data_imports_ui_static_message_pane_new_with_pango (DATA_IMPORTS_UI_NO_PLUGINS_ENABLED_MESSAGE);
#line 314 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp78_ = _tmp77_;
#line 314 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_data_imports_dialog_install_pane (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp78_, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 314 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_tmp78_);
#line 315 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_data_imports_dialog_set_close_button_mode (self);
#line 2165 "DataImportsUI.c"
	}
#line 318 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 210 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	loaded_services = (_vala_array_free (loaded_services, loaded_services_length1, (GDestroyNotify) g_object_unref), NULL);
#line 210 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_free0 (label);
#line 210 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_free0 (title);
#line 210 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return self;
#line 2177 "DataImportsUI.c"
}


DataImportsUIDataImportsDialog*
data_imports_ui_data_imports_dialog_new (void)
{
#line 210 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return data_imports_ui_data_imports_dialog_construct (DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG);
#line 2186 "DataImportsUI.c"
}


DataImportsUIDataImportsDialog*
data_imports_ui_data_imports_dialog_get_or_create_instance (void)
{
	DataImportsUIDataImportsDialog* result = NULL;
	DataImportsUIDataImportsDialog* _tmp0_;
	DataImportsUIDataImportsDialog* _tmp2_;
	DataImportsUIDataImportsDialog* _tmp3_;
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = data_imports_ui_data_imports_dialog_instance;
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp0_ == NULL) {
#line 2201 "DataImportsUI.c"
		DataImportsUIDataImportsDialog* _tmp1_;
#line 323 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp1_ = data_imports_ui_data_imports_dialog_new ();
#line 323 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_object_ref_sink (_tmp1_);
#line 323 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (data_imports_ui_data_imports_dialog_instance);
#line 323 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_data_imports_dialog_instance = _tmp1_;
#line 2211 "DataImportsUI.c"
	}
#line 325 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = data_imports_ui_data_imports_dialog_instance;
#line 325 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 325 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	result = _tmp3_;
#line 325 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return result;
#line 2221 "DataImportsUI.c"
}


void
data_imports_ui_data_imports_dialog_terminate_instance (void)
{
	DataImportsUIDataImportsDialog* _tmp0_;
#line 329 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = data_imports_ui_data_imports_dialog_instance;
#line 329 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp0_ != NULL) {
#line 2233 "DataImportsUI.c"
		DataImportsUIDataImportsDialog* _tmp1_;
#line 330 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp1_ = data_imports_ui_data_imports_dialog_instance;
#line 330 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_data_imports_dialog_terminate (_tmp1_);
#line 2239 "DataImportsUI.c"
	}
#line 332 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (data_imports_ui_data_imports_dialog_instance);
#line 332 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_data_imports_dialog_instance = NULL;
#line 2245 "DataImportsUI.c"
}


static gboolean
data_imports_ui_data_imports_dialog_on_window_close (DataImportsUIDataImportsDialog* self,
                                                     GdkEventAny* evt)
{
	gboolean result = FALSE;
#line 335 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self), FALSE);
#line 335 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (evt != NULL, FALSE);
#line 336 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_debug ("DataImportsUI.vala:336: DataImportsDialog: on_window_close( ): invoked" \
".");
#line 337 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_data_imports_dialog_terminate (self);
#line 339 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	result = TRUE;
#line 339 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return result;
#line 2266 "DataImportsUI.c"
}


static void
data_imports_ui_data_imports_dialog_on_service_changed (DataImportsUIDataImportsDialog* self)
{
	gchar* service_name = NULL;
	GtkComboBoxText* _tmp0_;
	gchar* _tmp1_;
	SpitDataImportsService* selected_service = NULL;
	SpitDataImportsService** services = NULL;
	gint _tmp2_;
	SpitDataImportsService** _tmp3_;
	gint services_length1;
	gint _services_size_;
	SpitDataImportsService** _tmp4_;
	gint _tmp4__length1;
	SpitDataImportsService* _tmp11_;
	ConfigFacade* _tmp12_;
	ConfigFacade* _tmp13_;
	SpitDataImportsService* _tmp14_;
	const gchar* _tmp15_;
	SpitDataImportsService* _tmp16_;
	SpitDataImportsConcreteDataImportsHost* _tmp17_;
	SpitDataImportsConcreteDataImportsHost* _tmp18_;
#line 342 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 343 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_debug ("DataImportsUI.vala:343: DataImportsDialog: on_service_changed invoked.");
#line 344 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->service_selector_box;
#line 344 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = gtk_combo_box_text_get_active_text (_tmp0_);
#line 344 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	service_name = _tmp1_;
#line 346 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	selected_service = NULL;
#line 347 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = spit_data_imports_load_all_services (&_tmp2_);
#line 347 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	services = _tmp3_;
#line 347 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	services_length1 = _tmp2_;
#line 347 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_services_size_ = services_length1;
#line 348 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp4_ = services;
#line 348 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp4__length1 = services_length1;
#line 2316 "DataImportsUI.c"
	{
		SpitDataImportsService** service_collection = NULL;
		gint service_collection_length1 = 0;
		gint _service_collection_size_ = 0;
		gint service_it = 0;
#line 348 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		service_collection = _tmp4_;
#line 348 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		service_collection_length1 = _tmp4__length1;
#line 348 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		for (service_it = 0; service_it < _tmp4__length1; service_it = service_it + 1) {
#line 2328 "DataImportsUI.c"
			SpitDataImportsService* _tmp5_;
			SpitDataImportsService* service = NULL;
#line 348 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp5_ = _g_object_ref0 (service_collection[service_it]);
#line 348 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			service = _tmp5_;
#line 2335 "DataImportsUI.c"
			{
				SpitDataImportsService* _tmp6_;
				const gchar* _tmp7_;
				const gchar* _tmp8_;
#line 349 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				_tmp6_ = service;
#line 349 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				_tmp7_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 349 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				_tmp8_ = service_name;
#line 349 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				if (g_strcmp0 (_tmp7_, _tmp8_) == 0) {
#line 2348 "DataImportsUI.c"
					SpitDataImportsService* _tmp9_;
					SpitDataImportsService* _tmp10_;
#line 350 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp9_ = service;
#line 350 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp10_ = _g_object_ref0 (_tmp9_);
#line 350 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_g_object_unref0 (selected_service);
#line 350 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					selected_service = _tmp10_;
#line 351 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_g_object_unref0 (service);
#line 351 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					break;
#line 2363 "DataImportsUI.c"
				}
#line 348 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				_g_object_unref0 (service);
#line 2367 "DataImportsUI.c"
			}
		}
	}
#line 354 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp11_ = selected_service;
#line 354 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_vala_assert (_tmp11_ != NULL, "selected_service != null");
#line 356 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp12_ = config_facade_get_instance ();
#line 356 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp13_ = _tmp12_;
#line 356 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp14_ = selected_service;
#line 356 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp15_ = spit_pluggable_get_id (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 356 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	configuration_facade_set_last_used_dataimports_service (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp15_);
#line 356 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_tmp13_);
#line 358 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp16_ = selected_service;
#line 358 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp17_ = spit_data_imports_concrete_data_imports_host_new (_tmp16_, self);
#line 358 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->host);
#line 358 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->host = _tmp17_;
#line 359 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp18_ = self->priv->host;
#line 359 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	spit_data_imports_plugin_host_start_importing (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 342 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	services = (_vala_array_free (services, services_length1, (GDestroyNotify) g_object_unref), NULL);
#line 342 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (selected_service);
#line 342 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_free0 (service_name);
#line 2405 "DataImportsUI.c"
}


static void
data_imports_ui_data_imports_dialog_on_close_cancel_clicked (DataImportsUIDataImportsDialog* self)
{
#line 362 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 363 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_debug ("DataImportsUI.vala:363: DataImportsDialog: on_close_cancel_clicked( ):" \
" invoked.");
#line 365 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_data_imports_dialog_terminate (self);
#line 2418 "DataImportsUI.c"
}


static void
data_imports_ui_data_imports_dialog_terminate (DataImportsUIDataImportsDialog* self)
{
	SpitDataImportsConcreteDataImportsHost* _tmp0_;
#line 368 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 369 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_debug ("DataImportsUI.vala:369: DataImportsDialog: terminate( ): invoked.");
#line 371 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->host;
#line 371 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp0_ != NULL) {
#line 2434 "DataImportsUI.c"
		SpitDataImportsConcreteDataImportsHost* _tmp1_;
#line 372 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp1_ = self->priv->host;
#line 372 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		spit_data_imports_plugin_host_stop_importing (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 373 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (self->priv->host);
#line 373 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		self->priv->host = NULL;
#line 2444 "DataImportsUI.c"
	}
#line 376 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 377 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (data_imports_ui_data_imports_dialog_instance);
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_data_imports_dialog_instance = NULL;
#line 2454 "DataImportsUI.c"
}


static void
data_imports_ui_data_imports_dialog_set_large_window_mode (DataImportsUIDataImportsDialog* self)
{
	GtkBox* _tmp0_;
#line 381 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 382 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_LARGE_WINDOW_WIDTH, DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_LARGE_WINDOW_HEIGHT);
#line 383 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->central_area_layouter;
#line 383 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_LARGE_WINDOW_WIDTH - DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_BORDER_REGION_WIDTH, DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_LARGE_WINDOW_HEIGHT - DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_BORDER_REGION_HEIGHT);
#line 385 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 2472 "DataImportsUI.c"
}


static void
data_imports_ui_data_imports_dialog_set_colossal_window_mode (DataImportsUIDataImportsDialog* self)
{
	GtkBox* _tmp0_;
#line 388 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 389 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_COLOSSAL_WINDOW_WIDTH, DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_COLOSSAL_WINDOW_HEIGHT);
#line 390 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->central_area_layouter;
#line 390 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_COLOSSAL_WINDOW_WIDTH - DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_BORDER_REGION_WIDTH, DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_COLOSSAL_WINDOW_HEIGHT - DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_BORDER_REGION_HEIGHT);
#line 392 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 2490 "DataImportsUI.c"
}


static void
data_imports_ui_data_imports_dialog_set_standard_window_mode (DataImportsUIDataImportsDialog* self)
{
	GtkBox* _tmp0_;
#line 395 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 396 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_STANDARD_WINDOW_WIDTH, DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_STANDARD_WINDOW_HEIGHT);
#line 397 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->central_area_layouter;
#line 397 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_STANDARD_WINDOW_WIDTH - DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_BORDER_REGION_WIDTH, DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_STANDARD_WINDOW_HEIGHT - DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_BORDER_REGION_HEIGHT);
#line 399 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 2508 "DataImportsUI.c"
}


static void
data_imports_ui_data_imports_dialog_set_free_sizable_window_mode (DataImportsUIDataImportsDialog* self)
{
#line 402 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 403 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), TRUE);
#line 2519 "DataImportsUI.c"
}


static void
data_imports_ui_data_imports_dialog_clear_free_sizable_window_mode (DataImportsUIDataImportsDialog* self)
{
#line 406 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 407 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 2530 "DataImportsUI.c"
}


SpitDataImportsDialogPane*
data_imports_ui_data_imports_dialog_get_active_pane (DataImportsUIDataImportsDialog* self)
{
	SpitDataImportsDialogPane* result = NULL;
	SpitDataImportsDialogPane* _tmp0_;
	SpitDataImportsDialogPane* _tmp1_;
#line 410 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self), NULL);
#line 411 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->active_pane;
#line 411 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 411 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	result = _tmp1_;
#line 411 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return result;
#line 2550 "DataImportsUI.c"
}


void
data_imports_ui_data_imports_dialog_set_close_button_mode (DataImportsUIDataImportsDialog* self)
{
	GtkButton* _tmp0_;
	GtkButton* _tmp1_;
#line 414 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 415 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->close_cancel_button;
#line 415 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_button_set_label (_tmp0_, _ ("_Close"));
#line 416 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = self->priv->close_cancel_button;
#line 416 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_window_set_default (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget));
#line 2569 "DataImportsUI.c"
}


void
data_imports_ui_data_imports_dialog_set_cancel_button_mode (DataImportsUIDataImportsDialog* self)
{
	GtkButton* _tmp0_;
#line 419 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 420 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->close_cancel_button;
#line 420 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_button_set_label (_tmp0_, _ ("_Cancel"));
#line 2583 "DataImportsUI.c"
}


void
data_imports_ui_data_imports_dialog_lock_service (DataImportsUIDataImportsDialog* self)
{
	GtkComboBoxText* _tmp0_;
#line 423 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 424 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->service_selector_box;
#line 424 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 2597 "DataImportsUI.c"
}


void
data_imports_ui_data_imports_dialog_unlock_service (DataImportsUIDataImportsDialog* self)
{
	GtkComboBoxText* _tmp0_;
#line 427 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 428 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->service_selector_box;
#line 428 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 2611 "DataImportsUI.c"
}


void
data_imports_ui_data_imports_dialog_install_pane (DataImportsUIDataImportsDialog* self,
                                                  SpitDataImportsDialogPane* pane)
{
	SpitDataImportsDialogPane* _tmp0_;
	GtkBox* _tmp6_;
	GtkWidget* _tmp7_;
	GtkWidget* _tmp8_;
	SpitDataImportsDialogPaneGeometryOptions geometry_options = 0;
	SpitDataImportsDialogPaneGeometryOptions _tmp9_;
	SpitDataImportsDialogPaneGeometryOptions _tmp11_;
	SpitDataImportsDialogPane* _tmp12_;
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_DIALOG_PANE (pane));
#line 432 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_debug ("DataImportsUI.vala:432: DataImportsDialog: install_pane( ): invoked.");
#line 434 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->active_pane;
#line 434 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp0_ != NULL) {
#line 2637 "DataImportsUI.c"
		SpitDataImportsDialogPane* _tmp1_;
		GtkBox* _tmp2_;
		SpitDataImportsDialogPane* _tmp3_;
		GtkWidget* _tmp4_;
		GtkWidget* _tmp5_;
#line 435 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_debug ("DataImportsUI.vala:435: DataImportsDialog: install_pane( ): a pane is " \
"already installed; removing it.");
#line 437 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp1_ = self->priv->active_pane;
#line 437 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		spit_data_imports_dialog_pane_on_pane_uninstalled (_tmp1_);
#line 438 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp2_ = self->priv->central_area_layouter;
#line 438 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp3_ = self->priv->active_pane;
#line 438 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp4_ = spit_data_imports_dialog_pane_get_widget (_tmp3_);
#line 438 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp5_ = _tmp4_;
#line 438 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_container_remove (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_container_get_type (), GtkContainer), _tmp5_);
#line 438 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_tmp5_);
#line 2661 "DataImportsUI.c"
	}
#line 441 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp6_ = self->priv->central_area_layouter;
#line 441 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp7_ = spit_data_imports_dialog_pane_get_widget (pane);
#line 441 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp8_ = _tmp7_;
#line 441 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (_tmp6_, _tmp8_, TRUE, TRUE, (guint) 0);
#line 441 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_tmp8_);
#line 442 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 444 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	geometry_options = spit_data_imports_dialog_pane_get_preferred_geometry (pane);
#line 446 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp9_ = geometry_options;
#line 446 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if ((_tmp9_ & SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_EXTENDED_SIZE) != 0) {
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_data_imports_dialog_set_large_window_mode (self);
#line 2683 "DataImportsUI.c"
	} else {
		SpitDataImportsDialogPaneGeometryOptions _tmp10_;
#line 448 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp10_ = geometry_options;
#line 448 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		if ((_tmp10_ & SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_COLOSSAL_SIZE) != 0) {
#line 449 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			data_imports_ui_data_imports_dialog_set_colossal_window_mode (self);
#line 2692 "DataImportsUI.c"
		} else {
#line 451 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			data_imports_ui_data_imports_dialog_set_standard_window_mode (self);
#line 2696 "DataImportsUI.c"
		}
	}
#line 453 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp11_ = geometry_options;
#line 453 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if ((_tmp11_ & SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_RESIZABLE) != 0) {
#line 454 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_data_imports_dialog_set_free_sizable_window_mode (self);
#line 2705 "DataImportsUI.c"
	} else {
#line 456 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_data_imports_dialog_clear_free_sizable_window_mode (self);
#line 2709 "DataImportsUI.c"
	}
#line 458 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp12_ = _g_object_ref0 (pane);
#line 458 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->active_pane);
#line 458 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->active_pane = _tmp12_;
#line 459 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	spit_data_imports_dialog_pane_on_pane_installed (pane);
#line 2719 "DataImportsUI.c"
}


static void
data_imports_ui_data_imports_dialog_class_init (DataImportsUIDataImportsDialogClass * klass)
{
#line 191 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_data_imports_dialog_parent_class = g_type_class_peek_parent (klass);
#line 191 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_type_class_add_private (klass, sizeof (DataImportsUIDataImportsDialogPrivate));
#line 191 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_ui_data_imports_dialog_finalize;
#line 2732 "DataImportsUI.c"
}


static void
data_imports_ui_data_imports_dialog_instance_init (DataImportsUIDataImportsDialog * self)
{
#line 191 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv = DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_GET_PRIVATE (self);
#line 2741 "DataImportsUI.c"
}


static void
data_imports_ui_data_imports_dialog_finalize (GObject * obj)
{
	DataImportsUIDataImportsDialog * self;
#line 191 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialog);
#line 204 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->service_selector_box);
#line 205 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->central_area_layouter);
#line 206 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->close_cancel_button);
#line 207 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->active_pane);
#line 208 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->host);
#line 191 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	G_OBJECT_CLASS (data_imports_ui_data_imports_dialog_parent_class)->finalize (obj);
#line 2763 "DataImportsUI.c"
}


GType
data_imports_ui_data_imports_dialog_get_type (void)
{
	static volatile gsize data_imports_ui_data_imports_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_ui_data_imports_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsUIDataImportsDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_ui_data_imports_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsUIDataImportsDialog), 0, (GInstanceInitFunc) data_imports_ui_data_imports_dialog_instance_init, NULL };
		GType data_imports_ui_data_imports_dialog_type_id;
		data_imports_ui_data_imports_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "DataImportsUIDataImportsDialog", &g_define_type_info, 0);
		g_once_init_leave (&data_imports_ui_data_imports_dialog_type_id__volatile, data_imports_ui_data_imports_dialog_type_id);
	}
	return data_imports_ui_data_imports_dialog_type_id__volatile;
}


static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



